@@ -16,7 +16,7 @@ from datetime import datetime as dt
 #from pandas_datareader import data
 
 from napoleontoolbox.connector import shifting_utility
-from npxlogger import log
+
 # Local packages
 
 __all__ = ['NaPoleonXConnector']
@@ -78,7 +78,7 @@ def fetch_equity_daily_data(data = None, ticker=None, provider = 'yahoo', starti
     try:
         yahoo_ticker = yahoo_tickers_equivalents[ticker]
     except:
-        log.info('No yahoo ticker equivalent for this ticker. Check dictionary of yahoo tickers equivalents')
+        print('No yahoo ticker equivalent for this ticker. Check dictionary of yahoo tickers equivalents')
 
     if provider == 'yahoo':
         data_df = None# data.DataReader(yahoo_ticker, provider, starting_date, running_date)
@@ -87,7 +87,7 @@ def fetch_equity_daily_data(data = None, ticker=None, provider = 'yahoo', starti
         data_df.to_pickle(local_root_directory+filename)
         return data_df
     else:
-        log.info('This provider has not been set up yet.')
+        print('This provider has not been set up yet.')
         return
 
 def fetch_delayed_crypto_daily_data(frequence = 'daily', ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix='_daily_returns.pkl', refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = 'binance', delay = 0):
