@@ -4,6 +4,7 @@ from collections import OrderedDict
 from dataclasses import dataclass
 from typing import List
 
+from arch import arch_model
 from pandas import Timestamp, Series, DataFrame
 from pandas._libs.tslibs.timedeltas import Timedelta
 from statsmodels.stats.diagnostic import acorr_lm
@@ -44,10 +45,12 @@ class GarchEstimation(object):
     def quotes(self):
         return self.__quotes
 
-    def ts_plot(self):
+    def get_returns(self):
         prices = Series(self.quotes).sort_index()
-        returns = (prices / prices.shift(1) - 1).dropna()
-        return tsplot(returns, lags=20)
+        return (prices / prices.shift(1) - 1).dropna()
+
+    def ts_plot(self):
+        return tsplot(self.get_returns(), lags=20)
 
     @property
     def parameters(self):
@@ -75,14 +78,31 @@ class GarchEstimation(object):
         res = ArchTestResult(lm_stat, lm_pval, f_stat, f_val)
         return DataFrame.from_dict(res.__dict__, orient="index")
 
+    def garch_estimation(self):
+        garch = arch_model(self.get_returns() * 100, vol='GARCH', p=self.__parameters.p, q=self.__parameters.q,
+                           dist="Normal")
+        DataFrame([self.get_returns().rolling(window=10).std(), garch.fit().conditional_volatility]).transpose().plot()
+        df = DataFrame(self.get_returns().rolling(window=10).std().dropna()).join(
+            garch.fit().conditional_volatility / 100)
+        signals = (df[0] - df['cond_vol'] > 0).map(lambda x: -1 if x == True else 1)
+        returns = OrderedDict(self.get_returns().to_dict())
+        strat_returns = OrderedDict({date: signals.get(date - Timedelta(hours=1)) * returns.get(date) for date, ret in
+                         returns.items() if signals.get(date - Timedelta(hours=1)) is not None})
+
+        levels = OrderedDict()
+        levels[min(strat_returns.keys())] = self.quotes.get(min(strat_returns.keys()))
+        for date,expected_return in strat_returns.items():
+            if not date in levels:
+                levels[date]=levels.get(date-Timedelta(hours=1))*(1+strat_returns.get(date))
 
 if __name__ == '__main__':
     params = GarchEstimationParams(
         start_date=Timestamp.utcnow() - Timedelta(days=360),
-        end_date=Timestamp.utcnow() - Timedelta(minutes=60),
+        end_date=Timestamp.utcnow() - Timedelta(minutes=1),
         underlyings=["ETH-USD"]
     )
     garch = GarchEstimation(params)
-    garch.ts_plot()
-    arch_test = garch.residuals_autocorr_test()
+    # garch.ts_plot()
+    # arch_test = garch.residuals_autocorr_test()
+    estimation = garch.garch_estimation()
     end = True
