@@ -12,14 +12,15 @@ from napoleontoolbox.rebalancing import allocation
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, save_model=False, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_suffix='_returns.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252, transaction_costs = None):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, save_model=False, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_suffix='_returns.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252, transaction_costs = None, crypto_lo = False):
         super().__init__()
-        self.supervision_npy_file_suffix=supervision_npy_file_suffix
-        self.macro_supervision_npy_file_suffix=macro_supervision_npy_file_suffix
-        self.features_saving_suffix=features_saving_suffix
+        self.supervision_npy_file_suffix = supervision_npy_file_suffix
+        self.macro_supervision_npy_file_suffix = macro_supervision_npy_file_suffix
+        self.features_saving_suffix = features_saving_suffix
         self.features_names_saving_suffix=features_names_saving_suffix
         self.returns_pkl_file_suffix=returns_pkl_file_suffix
-        self.returns_pkl_file_name = running_date.strftime('%d_%b_%Y')+returns_pkl_file_suffix
+
+
         self.local_root_directory=local_root_directory
         self.user=user
         self.n_start = n_start
@@ -38,7 +39,11 @@ class AbstractRunner(ABC):
         self.hrc_allocation = True
         self.mdp_allocation = True
         self.transaction_costs = None
-
+        self.cypto_lo = crypto_lo
+        if self.cypto_lo:
+            self.returns_pkl_file_name =  'crypto_lo_' + self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y') + self.returns_pkl_file_suffix
+        else :
+            self.returns_pkl_file_name = self.running_date.strftime('%d_%b_%Y') + self.returns_pkl_file_suffix
     @abstractmethod
     def runTrial(self,saver, seed,  n, s, low_bound, up_bound):
         pass
@@ -69,6 +74,7 @@ class SimpleEnsemblingRunner(AbstractRunner):
         print('Launching computation with parameters : '+savingKey)
 
         df = pd.read_pickle(self.local_root_directory + self.returns_pkl_file_name)
+
         print(df.columns)
         df['Date'] = pd.to_datetime(df['Date'])
         df = df.set_index('Date')
