@@ -14,6 +14,16 @@ from napoleontoolbox.parallel_run import signal_result_analyzer
 from sklearn.metrics import accuracy_score
 from functools import partial
 
+import hashlib
+
+
+def get_readable_label(signal_parameters):
+    run_json_string = signal_utility.recover_to_sql_column_format(signal_parameters)
+    salty = str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
+    params = json.loads(run_json_string)
+    readable_label = params['signal_type'] + str(params['trigger']) + salty
+    return readable_label
+
 
 def unjsonize_list_run_results(local_root_directory, list_pkl_file_name):
     signals_list = napoleon_connector.load_pickled_list(local_root_directory=local_root_directory,
@@ -399,6 +409,72 @@ def compute_signals_weights_perf(data = None, optimal_weights = None, starting_d
     return hourly_df, sharpe_strat, sharpe_strat_without, sharpe_under
 
 
+def select_signals(data_df = None, metric = None, number = None, transaction_cost = False, one_per_type = False, mapping = None, number_per_year = 252, transcribed = False):
+
+    if 'close_return' not in data_df.columns and 'close' in data_df.columns :
+        data_df['close_return'] = data_df['close'].pct_change()
+
+    metrics_results ={}
+    for sig in data_df.columns:
+        isSignal = False
+        if transcribed:
+            isSignal = sig != 'close' and sig != 'close_return' and sig != 'date'
+        else:
+            isSignal = 'signal' in sig
+
+
+        if isSignal:
+            temp_df = data_df[['close_return', sig]].copy()
+            temp_df = temp_df.rename(columns={sig: "signal"}, errors="raise")
+            freqly_df, _ = signal_utility.reconstitute_signal_perf(data=temp_df, transaction_cost=transaction_cost,                                                                   print_turnover=False, recompute_return=False)
+            strat_metric = None
+            if metric == 'sharpe':
+                strat_metric = metrics.sharpe(freqly_df['perf_return'].dropna(), period=number_per_year, from_ret=True)
+            elif metric == 'calmar':
+                strat_metric = metrics.calmar(freqly_df['reconstituted_perf'].dropna(), period=number_per_year)
+            elif metric == 'drawdown':
+                strat_metric = metrics.mdd(freqly_df['perf_return'].dropna())
+            elif metric == 'performance':
+                strat_metric = metrics.annual_return(freqly_df['reconstituted_perf'].dropna())
+            metrics_results[sig] = [strat_metric]
+
+    metrics_results_df = pd.DataFrame.from_dict(metrics_results)
+    metrics_results_df = metrics_results_df.T
+    metrics_results_df.columns = [metric]
+    metrics_results_df['signal'] = metrics_results_df.index
+
+    if one_per_type and mapping is not None :
+        inv_map = {v: k for k, v in mapping.to_dict('records')[0].items()}
+        def get_algo_type(string_to_parse):
+            type = ''
+            try:
+                type = signal_utility.unjsonize_list_run_results_list([string_to_parse])[0]['signal_type']
+            except Exception as err:
+                print("Parsing signal type error: {0}".format(err))
+            return type
+        type_map = {}
+        for k, v in inv_map.items():
+            type = get_algo_type(v)
+            type_map[k] = type
+        def get_signal_type(row):
+            return type_map[row['signal']]
+
+        metrics_results_df['type'] = metrics_results_df.apply(get_signal_type, axis=1)
+        metrics_results_df = metrics_results_df.groupby('type').max()
+
+
+    number = min(len(metrics_results_df), number)
+    if metric == 'drawdown':
+        metrics_results_df = metrics_results_df.sort_values(by = [metric],ascending=True).iloc[:number]
+    else :
+        metrics_results_df = metrics_results_df.sort_values(by = [metric],ascending=False).iloc[:number]
+    metrics_results_df['type'] = metrics_results_df.index
+    metrics_results_df.index = metrics_results_df['signal']
+    new_sigs = list(metrics_results_df.index)
+    new_sigs_dic = metrics_results_df[['signal','type']].to_dict()['type']
+    return new_sigs, new_sigs_dic
+
+
 def recompute_perf_returns(signals_df, close_df, transac_cost=True, print_turnover = False):
     results_df = pd.concat([signals_df, close_df], axis=1).reindex(signals_df.index)
     if 'close_return' not in results_df.columns:
